@@ -20,6 +20,7 @@
 #include "findsubtitlesconfigdialog.h"
 #include "simplehttp.h"
 #include "osparser.h"
+#include "filehash.h"
 #include "languages.h"
 #include <QStandardItemModel>
 #include <QSortFilterProxyModel>
@@ -38,6 +39,7 @@
 #include "subchooserdialog.h"
 #include "quazip.h"
 #include "quazipfile.h"
+#include "fixsubs.h"
 #include <QTemporaryFile>
 #include <QBuffer>
 #endif
@@ -128,11 +130,13 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 	include_lang_on_filename = true;
 
 	file_downloader = new FileDownloader(this);
-        file_downloader->setModal(false);
+	file_downloader->setModal(false);
 	connect( file_downloader, SIGNAL(downloadFailed(QString)),
              this, SLOT(showError(QString)), Qt::QueuedConnection );
 	connect( file_downloader, SIGNAL(downloadFinished(const QByteArray &)),
              this, SLOT(archiveDownloaded(const QByteArray &)), Qt::QueuedConnection );
+	connect( this, SIGNAL(subtitleDownloaded(const QString &)),
+             this, SLOT(fixSubtitles(const QString &)) );
 #endif
 
 	// Actions
@@ -152,6 +156,9 @@ FindSubtitlesWindow::FindSubtitlesWindow( QWidget * parent, Qt::WindowFlags f )
 
 	language_filter->setCurrentIndex(0);
 
+	// Opensubtitles server
+	os_server = "http://www.opensubtitles.org";
+
 	// Proxy
 	use_proxy = false;
 	proxy_type = QNetworkProxy::HttpProxy;
@@ -199,14 +206,31 @@ void FindSubtitlesWindow::retranslateStrings() {
 	QString current_language = language_filter->itemData(language_filter->currentIndex()).toString();
 	language_filter->clear();
 
-	QMap<QString,QString> l = Languages::list();
-	QMapIterator<QString, QString> i(l);
-	while (i.hasNext()) {
-		i.next();
-		language_filter->addItem( i.value() + " (" + i.key() + ")", i.key() );
+	QMap<QString,QString> l1 = Languages::most_used_list();
+	QMapIterator<QString, QString> i1(l1);
+	while (i1.hasNext()) {
+		i1.next();
+		language_filter->addItem( i1.value() + " (" + i1.key() + ")", i1.key() );
 	}
+	language_filter->addItem( tr("Portuguese - Brasil") + " (pb)", "pb");
 	language_filter->model()->sort(0);
+	#if QT_VERSION >= 0x040400
+	language_filter->insertSeparator(language_filter->count());
+	#endif
+
+	QMap<QString,QString> l2 = Languages::list();
+	QMapIterator<QString, QString> i2(l2);
+	while (i2.hasNext()) {
+		i2.next();
+		if (language_filter->findData(i2.key()) == -1) {
+			language_filter->addItem( i2.value() + " (" + i2.key() + ")", i2.key() );
+		}
+	}
+	//language_filter->model()->sort(0);
 	language_filter->insertItem( 0, tr("All"), "*" );
+	#if QT_VERSION >= 0x040400
+	language_filter->insertSeparator(1);
+	#endif
 	//language_filter->setCurrentIndex(language_index);
 	language_filter->setCurrentIndex(language_filter->findData(current_language));
 
@@ -240,11 +264,11 @@ void FindSubtitlesWindow::setMovie(QString filename) {
 	file_chooser->setText(filename);
 	table->setRowCount(0);
 
-	QString hash = OSParser::calculateHash(filename);
+	QString hash = FileHash::calculateHash(filename);
 	if (hash.isEmpty()) {
 		qWarning("FindSubtitlesWindow::setMovie: hash invalid. Doing nothing.");
 	} else {
-		QString link = "http://www.opensubtitles.org/search/sublanguageid-all/moviehash-" + hash + "/simplexml";
+		QString link = os_server + "/search/sublanguageid-all/moviehash-" + hash + "/simplexml";
 		qDebug("FindSubtitlesWindow::setMovie: link: '%s'", link.toLatin1().constData());
 		downloader->download(link);
 		last_file = filename;
@@ -541,7 +565,7 @@ bool FindSubtitlesWindow::uncompressZip(const QString & filename, const QString
 			qDebug("FindSubtitlesWindow::uncompressZip: extracted %s ok: %d", file.toUtf8().constData(), ok);
 			if (ok) extracted_count++;
 		}
-		status->setText(tr("%1 subtitle(s) extracted","", extracted_count).arg(extracted_count));
+		status->setText(tr("%n subtitle(s) extracted","", extracted_count));
 		if (extracted_count > 0) {
 			emit subtitleDownloaded( output_path +"/"+ files_to_extract[0] );
 		}
@@ -593,6 +617,19 @@ bool FindSubtitlesWindow::extractFile(QuaZip & zip, const QString & filename, co
 	return true;
 }
 
+void FindSubtitlesWindow::fixSubtitles(const QString & filename) {
+	qDebug("FindSubtitlesWindow::fixSubtitles: %s", filename.toUtf8().constData());
+
+	QFileInfo fi(filename);
+	if (fi.suffix().toLower() == "sub") {
+		qDebug("FindSubtitlesWindow::fixSubtitles: fixing end of lines");
+		if (FixSubtitles::fix(filename) != FixSubtitles::NoError) {
+			status->setText( tr("Error fixing the subtitle lines") );
+			qDebug("FindSubtitlesWindow::fixSubtitles: error fixing the subtitles");
+		}
+	}
+}
+
 #endif
 
 void FindSubtitlesWindow::on_configure_button_clicked() {
@@ -600,6 +637,7 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 
 	FindSubtitlesConfigDialog d(this);
 
+	d.setServer( os_server );
 	d.setUseProxy( use_proxy );
 	d.setProxyHostname( proxy_host );
 	d.setProxyPort( proxy_port );
@@ -608,6 +646,7 @@ void FindSubtitlesWindow::on_configure_button_clicked() {
 	d.setProxyType( proxy_type );
 
 	if (d.exec() == QDialog::Accepted) {
+		os_server = d.server();
 		use_proxy = d.useProxy();
 		proxy_host = d.proxyHostname();
 		proxy_port = d.proxyPort();
@@ -646,6 +685,7 @@ void FindSubtitlesWindow::saveSettings() {
 
 	set->beginGroup("findsubtitles");
 
+	set->setValue("server", os_server);
 	set->setValue("language", language());
 #ifdef DOWNLOAD_SUBS
 	set->setValue("include_lang_on_filename", includeLangOnFilename());
@@ -665,6 +705,7 @@ void FindSubtitlesWindow::loadSettings() {
 
 	set->beginGroup("findsubtitles");
 
+	os_server = set->value("server", os_server).toString();
 	setLanguage( set->value("language", language()).toString() );
 #ifdef DOWNLOAD_SUBS
 	setIncludeLangOnFilename( set->value("include_lang_on_filename", includeLangOnFilename()).toBool() );
