@@ -103,6 +103,9 @@ signals:
 protected:
 	bool uncompressZip(const QString & filename, const QString & output_path, const QString & preferred_output_name);
 	bool extractFile(QuaZip & zip, const QString & filename, const QString & output_name);
+
+protected slots:
+	void fixSubtitles(const QString & filename);
 #endif
 
 protected:
@@ -120,6 +123,9 @@ protected:
 	bool include_lang_on_filename;
 #endif
 
+	// Opensubtitles server
+	QString os_server;
+
 	// Proxy
 	bool use_proxy;
 	int proxy_type;
