@@ -30,7 +30,11 @@
 #include <QDir>
 #include <QLocale>
 
-#if YOUTUBE_SUPPORT
+#if QT_VERSION >= 0x040400
+#include <QDesktopServices>
+#endif
+
+#ifdef YOUTUBE_SUPPORT
 #include "retrieveyoutubeurl.h"
 #endif
 
@@ -77,9 +81,12 @@ void Preferences::reset() {
 #ifdef PORTABLE_APP
 	screenshot_directory= "./screenshots";
 #else
-	if (QFile::exists(Paths::configPath() + "/screenshots")) {
-		screenshot_directory = Paths::configPath() + "/screenshots";
+	#if QT_VERSION < 0x040400
+	QString default_screenshot_path = Paths::configPath() + "/screenshots";
+	if (QFile::exists(default_screenshot_path)) {
+		screenshot_directory = default_screenshot_path;
 	}
+	#endif
 #endif
 
 	dont_remember_media_settings = false;
@@ -184,8 +191,8 @@ void Preferences::reset() {
 	cache_for_audiocds = 1000;
 	cache_for_tv = 3000;
 
-#if YOUTUBE_SUPPORT
-	yt_quality = RetrieveYoutubeUrl::MP4_360p;
+#ifdef YOUTUBE_SUPPORT
+	yt_quality = RetrieveYoutubeUrl::MP4_720p;
 #endif
 
 
@@ -252,16 +259,17 @@ void Preferences::reset() {
     mplayer_additional_video_filters="";
     mplayer_additional_audio_filters="";
 
+#ifdef LOG_MPLAYER
 	log_mplayer = true;
+	verbose_log = false;
+	autosave_mplayer_log = false;
+	mplayer_log_saveto = "";
+#endif
+#ifdef LOG_SMPLAYER
 	log_smplayer = true;
 	log_filter = ".*";
-	verbose_log = false;
 	save_smplayer_log = false;
-
-    //mplayer log autosaving
-    autosave_mplayer_log = false;
-    mplayer_log_saveto = "";
-    //mplayer log autosaving end
+#endif
 
 #if REPAINT_BACKGROUND_OPTION
 	// "Repaint video background" in the preferences dialog
@@ -437,17 +445,9 @@ void Preferences::reset() {
     /* *********
        Instances
        ********* */
-
-#ifdef Q_OS_WIN
-	// Some people reported smplayer doesn't start with this option enabled
-	// So now it's disabled by default on Windows
-	use_single_instance = false; 
-#else
+#ifdef SINGLE_INSTANCE
 	use_single_instance = true;
 #endif
-	use_autoport = true;
-	connection_port = 8000;
-	autoport = 0;
 
 
     /* ****************
@@ -455,7 +455,7 @@ void Preferences::reset() {
        **************** */
 
 	floating_control_margin = 0;
-	floating_control_width = 100; //100 %
+	floating_control_width = 70; //70 %
 	floating_control_animated = true;
 	floating_display_in_compact_mode = false;
 #ifndef Q_OS_WIN
@@ -496,7 +496,11 @@ void Preferences::save() {
 	set->setValue("driver/audio_output", ao);
 
 	set->setValue("use_screenshot", use_screenshot);
+	#if QT_VERSION >= 0x040400
+	set->setValue("screenshot_folder", screenshot_directory);
+	#else
 	set->setValue("screenshot_directory", screenshot_directory);
+	#endif
 
 	set->setValue("dont_remember_media_settings", dont_remember_media_settings);
 	set->setValue("dont_remember_time_pos", dont_remember_time_pos);
@@ -600,7 +604,7 @@ void Preferences::save() {
 	set->setValue("cache_for_audiocds", cache_for_audiocds);
 	set->setValue("cache_for_tv", cache_for_tv);
 
-#if YOUTUBE_SUPPORT
+#ifdef YOUTUBE_SUPPORT
 	set->setValue("youtube_quality", yt_quality);
 #endif
 
@@ -671,16 +675,17 @@ void Preferences::save() {
 	set->setValue("mplayer_additional_video_filters", mplayer_additional_video_filters);
 	set->setValue("mplayer_additional_audio_filters", mplayer_additional_audio_filters);
 
+#ifdef LOG_MPLAYER
 	set->setValue("log_mplayer", log_mplayer);
+	set->setValue("verbose_log", verbose_log);
+	set->setValue("autosave_mplayer_log", autosave_mplayer_log);
+	set->setValue("mplayer_log_saveto", mplayer_log_saveto);
+#endif
+#ifdef LOG_SMPLAYER
 	set->setValue("log_smplayer", log_smplayer);
 	set->setValue("log_filter", log_filter);
-	set->setValue("verbose_log", verbose_log);
 	set->setValue("save_smplayer_log", save_smplayer_log);
-
-    //mplayer log autosaving
-    set->setValue("autosave_mplayer_log", autosave_mplayer_log);
-    set->setValue("mplayer_log_saveto", mplayer_log_saveto);
-    //mplayer log autosaving end
+#endif
 
 #if REPAINT_BACKGROUND_OPTION
 	set->setValue("repaint_video_background", repaint_video_background);
@@ -856,13 +861,11 @@ void Preferences::save() {
     /* *********
        Instances
        ********* */
-
+#ifdef SINGLE_INSTANCE
 	set->beginGroup("instances");
-	set->setValue("use_single_instance", use_single_instance);
-	set->setValue("connection_port", connection_port);
-	set->setValue("use_autoport", use_autoport);
-	set->setValue("temp/autoport", autoport);
+	set->setValue("single_instance_enabled", use_single_instance);
 	set->endGroup(); // instances
+#endif
 
 
     /* ****************
@@ -919,7 +922,12 @@ void Preferences::load() {
 	ao = set->value("driver/audio_output", ao).toString();
 
 	use_screenshot = set->value("use_screenshot", use_screenshot).toBool();
+	#if QT_VERSION >= 0x040400
+	screenshot_directory = set->value("screenshot_folder", screenshot_directory).toString();
+	setupScreenshotFolder();
+	#else
 	screenshot_directory = set->value("screenshot_directory", screenshot_directory).toString();
+	#endif
 
 	dont_remember_media_settings = set->value("dont_remember_media_settings", dont_remember_media_settings).toBool();
 	dont_remember_time_pos = set->value("dont_remember_time_pos", dont_remember_time_pos).toBool();
@@ -1024,7 +1032,7 @@ void Preferences::load() {
 	cache_for_audiocds = set->value("cache_for_audiocds", cache_for_audiocds).toInt();
 	cache_for_tv = set->value("cache_for_tv", cache_for_tv).toInt();
 
-#if YOUTUBE_SUPPORT
+#ifdef YOUTUBE_SUPPORT
 	yt_quality = set->value("youtube_quality", yt_quality).toInt();
 #endif
 
@@ -1101,16 +1109,17 @@ void Preferences::load() {
 	mplayer_additional_video_filters = set->value("mplayer_additional_video_filters", mplayer_additional_video_filters).toString();
 	mplayer_additional_audio_filters = set->value("mplayer_additional_audio_filters", mplayer_additional_audio_filters).toString();
 
+#ifdef LOG_MPLAYER
 	log_mplayer = set->value("log_mplayer", log_mplayer).toBool();
+	verbose_log = set->value("verbose_log", verbose_log).toBool();
+	autosave_mplayer_log = set->value("autosave_mplayer_log", autosave_mplayer_log).toBool();
+	mplayer_log_saveto = set->value("mplayer_log_saveto", mplayer_log_saveto).toString();
+#endif
+#ifdef LOG_SMPLAYER
 	log_smplayer = set->value("log_smplayer", log_smplayer).toBool();
 	log_filter = set->value("log_filter", log_filter).toString();
-	verbose_log = set->value("verbose_log", verbose_log).toBool();
 	save_smplayer_log = set->value("save_smplayer_log", save_smplayer_log).toBool();
-
-    //mplayer log autosaving
-    autosave_mplayer_log = set->value("autosave_mplayer_log", autosave_mplayer_log).toBool();
-    mplayer_log_saveto = set->value("mplayer_log_saveto", mplayer_log_saveto).toString();
-    //mplayer log autosaving end
+#endif
 
 #if REPAINT_BACKGROUND_OPTION
 	repaint_video_background = set->value("repaint_video_background", repaint_video_background).toBool();
@@ -1287,13 +1296,11 @@ void Preferences::load() {
     /* *********
        Instances
        ********* */
-
+#ifdef SINGLE_INSTANCE
 	set->beginGroup("instances");
-	use_single_instance = set->value("use_single_instance", use_single_instance).toBool();
-	connection_port = set->value("connection_port", connection_port).toInt();
-	use_autoport = set->value("use_autoport", use_autoport).toBool();
-	autoport = set->value("temp/autoport", autoport).toInt();
+	use_single_instance = set->value("single_instance_enabled", use_single_instance).toBool();
 	set->endGroup(); // instances
+#endif
 
 
     /* ****************
@@ -1357,3 +1364,28 @@ double Preferences::monitor_aspect_double() {
 		return 0;
 	}
 }
+
+void Preferences::setupScreenshotFolder() {
+#if QT_VERSION >= 0x040400
+	if (screenshot_directory.isEmpty()) {
+		QString pdir = QDesktopServices::storageLocation(QDesktopServices::PicturesLocation);
+		if (pdir.isEmpty()) pdir = QDesktopServices::storageLocation(QDesktopServices::DocumentsLocation);
+		if (pdir.isEmpty()) pdir = QDesktopServices::storageLocation(QDesktopServices::HomeLocation);
+		if (pdir.isEmpty()) pdir = "/tmp";
+		if (!QFile::exists(pdir)) {
+			qWarning("Preferences::setupScreenshotFolder: folder '%s' does not exist. Using /tmp as fallback", pdir.toUtf8().constData());
+			pdir = "/tmp";
+		}
+		QString default_screenshot_path = pdir + "/smplayer_screenshots";
+		if (!QFile::exists(default_screenshot_path)) {
+			qDebug("Preferences::setupScreenshotFolder: creating '%s'", default_screenshot_path.toUtf8().constData());
+			if (!QDir().mkdir(default_screenshot_path)) {
+				qWarning("Preferences::setupScreenshotFolder: failed to create '%s'", default_screenshot_path.toUtf8().constData());
+			}
+		}
+		if (QFile::exists(default_screenshot_path)) {
+			screenshot_directory = default_screenshot_path;
+		}
+	}
+#endif
+}
